@@ -188,11 +188,11 @@ add_ci.tbl_svysummary <- function(x,
     imap(
       ~dplyr::mutate(
         .x,
-        fmt_fn = ifelse(.data$stat_name %in% c("estimate", "conf.low", "conf.high"),
+        fmt_fun = ifelse(.data$stat_name %in% c("estimate", "conf.low", "conf.high"),
                         list(style_fun[[.y]]),
-                        .data$fmt_fn)
+                        .data$fmt_fun)
       ) |>
-        cards::apply_fmt_fn()
+        cards::apply_fmt_fun()
     ) |>
     dplyr::bind_rows() |>
     cards::tidy_ard_column_order()
