@@ -22,14 +22,17 @@ gather_ard <- function(x) {
   check_class(x, "gtsummary")
 
   # cycle through the underlying tbls, and get ARD from each
-  if (inherits(x, c("tbl_stack", "tbl_merge", "tbl_uvregression"))) {
+  if (inherits(x, c("tbl_stack", "tbl_merge"))) {
     return(map(x[["tbls"]], gather_ard))
   }
 
   # the ARD for regression models is an additional calculation, so we don't do it by default
+  if (inherits(x, c("tbl_uvregression"))) {
+    x$cards$tbl_uvregression <- map(x[["tbls"]], ~gather_ard(.x)[[1]])
+  }
   if (inherits(x, "tbl_regression")) {
     check_pkg_installed("cardx")
-    return(cardx::ard_regression(x$inputs$x))
+    x$cards$tbl_regression <- cardx::ard_regression(x$inputs$x)
   }
 
   # grab ARD from standard place
