@@ -1,7 +1,6 @@
-#' Set a gtsummary theme
+#' Set gtsummary theme
 #'
 #' @description
-#' \lifecycle{maturing}
 #' Functions to **set**, **reset**, **get**, and evaluate **with** gtsummary themes.
 #'
 #' - `set_gtsummary_theme()` set a theme
@@ -18,78 +17,88 @@
 #' the default reporting style to match another journal, or your own
 #' personal style.
 #'
-#' @param x A named list defining a gtsummary theme.
-#' @param expr Expression to be evaluated with the theme specified in `x=` loaded
-#' @param env The environment in which to evaluate `expr=`
-#' @param msg_ignored_elements Default is NULL with no message printed. Pass a string
-#' that will be printed with `cli::cli_alert_info()`. The `"{elements}"`
-#' object contains vector of theme elements that will be overwritten and ignored.
-#' @inheritParams add_global_p
+#' @param x (named `list`)\cr
+#'   A named list defining a gtsummary theme.
+#' @param expr (`expression`)\cr
+#'   Expression to be evaluated with the theme specified in `x=` loaded
+#' @param env (`environment`)\cr
+#'   The environment in which to evaluate `expr=`
+#' @param msg_ignored_elements (`string`)\cr
+#'   Default is `NULL` with no message printed. Pass a string
+#'   that will be printed with `cli::cli_alert_info()`. The `"{elements}"`
+#'   object contains vector of theme elements that will be overwritten and ignored.
+#' @param quiet `r lifecycle::badge("deprecated")`
+#'
 #' @name set_gtsummary_theme
 #' @export
+#'
 #' @seealso [Themes vignette](https://www.danieldsjoberg.com/gtsummary/articles/themes.html)
 #' @seealso Available [gtsummary themes][theme_gtsummary]
 #' @examples
-#' \donttest{
 #' # Setting JAMA theme for gtsummary
 #' set_gtsummary_theme(theme_gtsummary_journal("jama"))
 #' # Themes can be combined by including more than one
 #' set_gtsummary_theme(theme_gtsummary_compact())
 #'
 #' set_gtsummary_theme_ex1 <-
-#'   trial %>%
-#'   dplyr::select(age, grade, trt) %>%
-#'   tbl_summary(by = trt) %>%
-#'   add_stat_label() %>%
+#'   trial |>
+#'   tbl_summary(by = trt, include = c(age, grade, trt)) |>
+#'   add_stat_label() |>
 #'   as_gt()
 #'
 #' # reset gtsummary theme
 #' reset_gtsummary_theme()
-#' }
-#' @section Example Output:
-#' \if{html}{Example}
-#'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "set_gtsummary_theme_ex1.png", width = "70")`
-#' }}
 NULL
 
-# ------------------------------------------------------------------------------
+# set_gtsummary_theme ----------------------------------------------------------
 #' @rdname set_gtsummary_theme
 #' @export
-set_gtsummary_theme <- function(x, quiet = NULL) {
-  # setting defaults -----------------------------------------------------------
-  quiet <- quiet %||% get_theme_element("pkgwide-lgl:quiet") %||% FALSE
+set_gtsummary_theme <- function(x, quiet) {
+  set_cli_abort_call()
+
+  # deprecation ----------------------------------------------------------------
+  if (!missing(quiet)) {
+    lifecycle::deprecate_warn(
+      when = "2.0.0",
+      what = "gtsummary::set_gtsummary_theme(quiet)",
+      details = "Argument has been ignored."
+    )
+  }
 
   # checking the input is a named list -----------------------------------------
-  if (rlang::is_empty(x)) {
+  if (is_empty(x)) {
     return(invisible())
   }
-  if (!inherits(x, "list") || is.null(names(x)) || "" %in% names(x)) {
-    stop("Argument `x=` must be  named list.", call. = FALSE)
+  if (!inherits(x, "list") || !is_named(x)) {
+    cli::cli_abort(
+      "The {.arg x} argument must be a named list.",
+      call = get_cli_abort_call()
+    )
   }
 
   # check that all the names are proper names that set gtsummary attributes ----
   if (!all(names(x) %in% df_theme_elements$name)) {
     not_name <- names(x) %>% setdiff(df_theme_elements$name)
-    stop(paste(
-      "List elements", quoted_list(not_name), "are not accepted theme elements."
-    ), call. = FALSE)
+    cli::cli_abort(
+      "The following names of {.arg x} are not accepted theme elemets: {.val {not_name}}.",
+      call = get_cli_abort_call()
+    )
   }
 
   # print name of theme if present ---------------------------------------------
-  if (!is.null(x$`pkgwide-str:theme_name`) && !isTRUE(quiet)) {
-    rlang::inform(glue("Setting theme `{x$`pkgwide-str:theme_name`}`"))
+  if (!is_empty(x$`pkgwide-str:theme_name`)) {
+    cli::cli_inform("Setting theme {.val {x$`pkgwide-str:theme_name`}}")
   }
 
   # adding theme elements to environment ---------------------------------------
-  rlang::env_bind(.env = env_gtsummary_theme, !!!x)
+  env_bind(.env = env_gtsummary_theme, !!!x)
 }
 
 # ------------------------------------------------------------------------------
 #' @rdname set_gtsummary_theme
 #' @export
 reset_gtsummary_theme <- function() {
+  set_cli_abort_call()
   # deleting theme environment if it exists
   rm(
     list = ls(envir = env_gtsummary_theme),
@@ -103,6 +112,7 @@ reset_gtsummary_theme <- function() {
 #' @rdname set_gtsummary_theme
 #' @export
 get_gtsummary_theme <- function() {
+  set_cli_abort_call()
   as.list(env_gtsummary_theme)
 }
 
@@ -117,16 +127,16 @@ with_gtsummary_theme <- function(x, expr,
 
   # on exit, restore theme -----------------------------------------------------
   on.exit(reset_gtsummary_theme(), add = TRUE)
-  on.exit(set_gtsummary_theme(current_theme, quiet = TRUE), add = TRUE)
+  on.exit(suppressMessages(set_gtsummary_theme(current_theme)), add = TRUE)
 
   # message ignored theme elements ---------------------------------------------
   .msg_ignored_elements(x, current_theme, msg_ignored_elements)
 
   # add specified theme --------------------------------------------------------
-  set_gtsummary_theme(suppressMessages(x), quiet = TRUE)
+  suppressMessages(set_gtsummary_theme(x))
 
   # evaluate expression
-  rlang::eval_tidy({{ expr }}, env = env)
+  eval_tidy({{ expr }}, env = env)
 }
 
 .msg_ignored_elements <- function(x, current_theme, msg) {
@@ -137,11 +147,11 @@ with_gtsummary_theme <- function(x, expr,
 
   # save vector of theme element names that will be ignored
   elements <-
-    x %>%
+    x |>
     imap(
       function(.x, .y) {
         # if theme element not currently set, return NULL
-        if (is.null(current_theme[[.y]])) {
+        if (is_empty(current_theme[[.y]])) {
           return(NULL)
         }
         # if theme element is already set and is different, return the name of the element
@@ -150,58 +160,66 @@ with_gtsummary_theme <- function(x, expr,
         }
         return(NULL)
       }
-    ) %>%
-    purrr::compact() %>%
+    ) |>
+    compact() |>
     unlist()
 
   # print message of ignored elements
-  if (!rlang::is_empty(elements)) {
-    cli::cli_alert_info(msg)
+  if (!is_empty(elements)) {
+    cli::cli_inform(msg)
   }
 
-  return(invisible())
+  invisible()
 }
 
 # ------------------------------------------------------------------------------
 #' @rdname set_gtsummary_theme
 #' @export
 check_gtsummary_theme <- function(x) {
+  set_cli_abort_call()
+
   # themes must be named lists
-  if (!inherits(x, "list") || !rlang::is_named(x)) {
-    cli::cli_alert_danger("{.code x=} must be a named list.")
+  if (!inherits(x, "list") || !is_named(x)) {
+    cli::cli_warn("The {.arg x} argument must be a named list.")
     return(invisible())
   }
 
   # check all names are true theme elements
-  if (any(!names(x) %in% df_theme_elements$name)) {
-    paste(
-      "Theme element(s) {.val {setdiff(names(x), df_theme_elements$name)}}",
-      "are not valid."
-    ) %>%
-      cli::cli_alert_danger()
-    return(invisible())
+  else if (!all(names(x) %in% df_theme_elements$name)) {
+    not_name <- names(x) %>% setdiff(df_theme_elements$name)
+    cli::cli_warn(
+      "The following names of {.arg x} are not accepted theme elemets: {.val {not_name}}."
+    )
   }
 
-  cli::cli_alert_success("Looks good!")
+  else cli::cli_alert_success("Looks good!")
+
   invisible()
 }
 
 # ------------------------------------------------------------------------------
 # this function grabs a gtsummary theme element if it exists
 # otherwise returns the default value
-get_theme_element <- function(x, default = NULL, eval = TRUE) {
-  # checking input REMOVED THIS CHECK IN v1.6.0 AND ADDED check_gtsummary_theme() instead
-  # if (!x %in% df_theme_elements$name) {
-  #   stop(glue("`x = '{x}'` is not a proper gtsummary theme element."), call. = FALSE)
-  # }
-
+get_theme_element <- function(x, default = NULL, eval = TRUE, env = caller_env()) {
   # returning theme element
   # if eval is FALSE, then returning the un-evaluated theme element
-  if (eval == FALSE) {
+  if (isFALSE(eval)) {
     return(env_gtsummary_theme[[x]] %||% default)
   }
 
   # the theme element is evaluated in the caller env so it may conditionally
   # set a default depending on other objects only known at the time it is called
-  rlang::eval_tidy(env_gtsummary_theme[[x]], env = rlang::caller_env()) %||% default
+  eval_tidy(env_gtsummary_theme[[x]], env = env) %||% default
 }
+
+get_deprecated_theme_element <- function(x, default = NULL, eval = TRUE, env = caller_env(), version = "2.0.0") {
+  if (!is_empty(env_gtsummary_theme[[x]])) {
+    lifecycle::deprecate_warn(
+      when = version,
+      what = I(glue("gtsummary theme element {shQuote(x)}"))
+    )
+  }
+
+  get_theme_element(x = x, default = default, eval = eval, env = env)
+}
+
