@@ -38,8 +38,8 @@
 #'   See below for details.
 #' @param missing,missing_text,missing_stat
 #'   Arguments dictating how and if missing values are presented:
-#'   - `missing`: must be one of `c("ifany", "no", "always")`
-#'   - `missing_text`: string indicating text shown on missing row. Default is `"Unknown"`
+#'   - `missing`: must be one of `c("ifany", "no", "always")`.
+#'   - `missing_text`: string indicating text shown on missing row. Default is `"Unknown"`.
 #'   - `missing_stat`: statistic to show on missing row. Default is `"{N_miss}"`.
 #'     Possible values are `N_miss`, `N_obs`, `N_nonmiss`, `p_miss`, `p_nonmiss`.
 #' @param sort ([`formula-list-selector`][syntax])\cr
@@ -49,6 +49,10 @@
 #' @param percent (`string`)\cr
 #'   Indicates the type of percentage to return.
 #'   Must be one of `c("column", "row", "cell")`. Default is `"column"`.
+#'
+#'   In rarer cases, you may need to define/override the typical denominators.
+#'   In these cases, pass an integer or a data frame. Refer to the
+#'   [`?cards::ard_categorical(denominator)`][cards::ard_categorical] help file for details.
 #' @param include ([`tidy-select`][dplyr::dplyr_tidy_select])\cr
 #'   Variables to include in the summary table. Default is `everything()`.
 #'
@@ -204,9 +208,19 @@ tbl_summary <- function(data,
   check_string(missing_stat)
 
 
-  if (missing(percent))
-    percent <- get_theme_element("tbl_summary-arg:percent", default = percent) # styler: off
-  percent <- arg_match(percent, values = c("column", "row", "cell"))
+  if (missing(percent)) {
+    percent <- get_theme_element("tbl_summary-arg:percent", default = percent)
+  }
+  if (is.character(percent)) {
+    percent <- arg_match(percent, values = c("column", "row", "cell"))
+  }
+  else if (!is.data.frame(percent) && !is_integerish(percent)) {
+    cli::cli_abort(
+      "The {.arg percent} argument must be one of {.val {c('column', 'row', 'cell')}} ({.emph the most common input}),
+         or a {.cls data.frame} or {.cls integer}; not a {.obj_type_friendly {percent}}.",
+      call = get_cli_abort_call()
+    )
+  }
 
   cards::process_formula_selectors(
     data = data[include],
@@ -327,7 +341,7 @@ tbl_summary <- function(data,
         scope_table_body(.list2tb(type, "var_type"), data),
         by = all_of(by),
         variables = all_categorical(FALSE),
-        fmt_fn = digits,
+        fmt_fun = digits,
         denominator = percent,
         stat_label = ~ default_stat_labels()
       ),
@@ -336,7 +350,7 @@ tbl_summary <- function(data,
         scope_table_body(.list2tb(type, "var_type"), data),
         by = all_of(by),
         variables = all_dichotomous(),
-        fmt_fn = digits,
+        fmt_fun = digits,
         denominator = percent,
         value = value,
         stat_label = ~ default_stat_labels()
@@ -350,14 +364,14 @@ tbl_summary <- function(data,
           .continuous_statistics_chr_to_fun(
             statistic[select(scope_table_body(.list2tb(type, "var_type"), data), all_continuous()) |> names()]
           ),
-        fmt_fn = digits,
+        fmt_fun = digits,
         stat_label = ~ default_stat_labels()
       ),
       cards::ard_attributes(data, variables = all_of(c(include, by)), label = label),
       cards::ard_missing(data,
                          variables = all_of(include),
                          by = all_of(by),
-                         fmt_fn = digits,
+                         fmt_fun = digits,
                          stat_label = ~ default_stat_labels()
       ),
       # adding total N
@@ -478,7 +492,8 @@ tbl_summary <- function(data,
   }
 
   obs_to_drop <- is.na(data[[by]])
-  cli::cli_inform("{.val {sum(obs_to_drop)}} missing rows in the {.val {by}} column have been removed.")
+  cli::cli_inform("{.val {sum(obs_to_drop)}} missing row{?s} in the {.val {by}}
+                  column {cli::qty(sum(obs_to_drop))}{?has/have} been removed.")
   dplyr::filter(data, !obs_to_drop)
 }
 
@@ -523,7 +538,9 @@ tbl_summary <- function(data,
 
   for (i in seq_along(sort[intersect(names(sort), names(data))])) {
     if (sort[[i]] %in% "frequency") {
+      lbl <- attr(data[[names(sort)[i]]], "label")
       data[[names(sort)[i]]] <- fct_infreq(data[[names(sort)[i]]])
+      attr(data[[names(sort)[i]]], "label") <- lbl
     }
   }
 
