@@ -5,6 +5,9 @@
 #'
 #' @param data (`survey.design`)\cr
 #'   A survey object created with created with `survey::svydesign()`
+#' @param percent (`string`)\cr
+#'   Indicates the type of percentage to return.
+#'   Must be one of `c("column", "row", "cell")`. Default is `"column"`.
 #' @inheritParams tbl_summary
 #'
 #' @inheritSection tbl_summary type and value arguments
@@ -114,10 +117,9 @@ tbl_svysummary <- function(data,
     )
   )
 
-  data$variables <- .drop_missing_by_obs(data$variables, by = by) # styler: off
+  data <- .svy_ignore_missing_by_obs(data, by = by, include)
   include <- setdiff(include, by) # remove by variable from list vars included
 
-
   if (missing(missing)) {
     missing <-
       get_theme_element("tbl_svysummary-arg:missing") %||%
@@ -286,7 +288,7 @@ tbl_svysummary <- function(data,
       cardx::ard_missing(data,
                          variables = all_of(include),
                          by = all_of(by),
-                         fmt_fn = digits,
+                         fmt_fun = digits,
                          stat_label = ~ default_stat_labels()),
       # tabulate by variable for header stats
       if (!is_empty(by)) {
@@ -299,7 +301,7 @@ tbl_svysummary <- function(data,
         data,
         by = all_of(by),
         variables = all_of(variables_categorical),
-        fmt_fn = digits[variables_categorical],
+        fmt_fun = digits[variables_categorical],
         denominator = percent,
         stat_label = ~ default_stat_labels()
       ),
@@ -308,7 +310,7 @@ tbl_svysummary <- function(data,
         data,
         by = all_of(by),
         variables = all_of(variables_dichotomous),
-        fmt_fn = digits[variables_dichotomous],
+        fmt_fun = digits[variables_dichotomous],
         denominator = percent,
         value = value[variables_dichotomous],
         stat_label = ~ default_stat_labels()
@@ -319,7 +321,7 @@ tbl_svysummary <- function(data,
         by = all_of(by),
         variables = all_of(variables_continuous),
         statistic = statistic_continuous,
-        fmt_fn = digits[variables_continuous],
+        fmt_fun = digits[variables_continuous],
         stat_label = ~ default_stat_labels()
       )
     ) |>
@@ -381,3 +383,30 @@ tbl_svysummary <- function(data,
   x
 }
 
+.svy_ignore_missing_by_obs <- function(data, by, include) {
+  if (is_empty(by) || !any(is.na(data$variables[[by]]))) {
+    return(data)
+  }
+
+  obs_to_drop <- is.na(data$variables[[by]])
+  cli::cli_inform(
+    "{.val {sum(obs_to_drop)}} row{?s} with missingness in the {.val {by}} column
+    {cli::qty(sum(obs_to_drop))}{?has/have} been removed with {.fun subset}."
+  )
+
+  # save original labels (subsetting removes labels)
+  original_lbs <- lapply(data$variables[c(by, include)], \(x) {attr(x, "label")})
+
+  # subset data
+  data <-
+    call2("subset", x = expr(data), subset = expr(!is.na(!!sym(by)))) |>
+    eval()
+
+  # restore column labels
+  for (v in c(by, include)) {
+    attr(data$variables[[v]], "label") <- original_lbs[[v]]
+  }
+
+  # return data
+  data
+}
