@@ -28,7 +28,7 @@ test_that("add_glance_source_note(include,label)", {
   )
 })
 
-test_that("add_glance_source_note(fmt_fn)", {
+test_that("add_glance_source_note(fmt_fun)", {
   expect_equal(
     lm(age ~ trt, trial) |>
       tbl_regression() |>
@@ -106,7 +106,7 @@ test_that("add_glance_table(include,label)", {
   )
 })
 
-test_that("add_glance_table(fmt_fn)", {
+test_that("add_glance_table(fmt_fun)", {
   expect_equal(
     lm(age ~ trt, trial) |>
       tbl_regression() |>
