@@ -7,7 +7,7 @@ test_that("add_p.tbl_cross() works", {
       tbl_cross(row = stage, col = trt) |>
       add_p()
   )
-  expect_equal(round(out$table_body$p.value[1], 4), 0.8662)
+  expect_equal(unname(round(out$table_body$p.value[1], 4)), 0.8662)
 })
 
 test_that("add_p.tbl_cross(source_note) works", {
@@ -16,7 +16,7 @@ test_that("add_p.tbl_cross(source_note) works", {
       tbl_cross(row = stage, col = trt) |>
       add_p(source_note = TRUE)
   )
-  expect_equal(round(out$table_body$p.value[1], 4), 0.8662)
+  expect_equal(unname(round(out$table_body$p.value[1], 4)), 0.8662)
 
   source_nt <- "Pearson's Chi-squared test, p=0.9"
   expect_equal(out$table_styling$source_note$source_note, source_nt)
