@@ -338,7 +338,7 @@ test_that("as_gt passes table indentation correctly", {
 
   # indentation removed
   tbl <- my_tbl_summary |>
-    modify_column_indent(columns = label, indent = 0)
+    modify_indent(columns = label, indent = 0)
   gt_tbl <- tbl |> as_gt()
 
   expect_equal(
