@@ -1,8 +1,8 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("broom.helpers", "cardx"), reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed(c("broom.helpers", "cardx")))
 
 test_that("tidy_standardize()", {
-  skip_if_not(is_pkg_installed(c("parameters", "effectsize"), reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed(c("parameters", "effectsize")))
 
   expect_snapshot(
     lm(age ~ grade + marker, trial) |>
@@ -11,7 +11,7 @@ test_that("tidy_standardize()", {
 })
 
 test_that("tidy_bootstrap()", {
-  skip_if_not(is_pkg_installed(c("parameters", "withr"), reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed(c("parameters", "withr")))
   withr::local_seed(11235)
 
   expect_error(
@@ -24,7 +24,7 @@ test_that("tidy_bootstrap()", {
 })
 
 test_that("tidy_wald_test()", {
-  skip_if_not(is_pkg_installed(c("aod"), reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed(c("aod")))
 
   expect_snapshot(
     lm(age ~ grade + marker, trial) |>
@@ -33,7 +33,7 @@ test_that("tidy_wald_test()", {
 })
 
 test_that("tidy_robust()", {
-  skip_if_not(is_pkg_installed(c("parameters", "insight"), reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed(c("parameters", "insight")))
 
   expect_snapshot(
     lm(age ~ grade + marker, trial) |>
