@@ -49,7 +49,7 @@ test_that("modify_caption() works with tbl_cross()", {
 })
 
 test_that("modify_caption() works with tbl_regression()", {
-  skip_if_not(is_pkg_installed("broom.helpers"))
+  skip_if_not(is_pkg_installed(c("cardx", "broom.helpers")))
 
   expect_equal(glm(response ~ age + grade, trial, family = binomial()) |>
                  tbl_regression(exponentiate = TRUE) |>
@@ -62,6 +62,7 @@ test_that("modify_caption() works with tbl_regression()", {
 })
 
 test_that("modify_caption() works with tbl_uvregression()", {
+  skip_if_not(is_pkg_installed(c("cardx", "broom.helpers")))
   expect_equal(tbl_uvregression(trial, method = glm, y = response, method.args = list(family = binomial),
                                 exponentiate = TRUE, include = c("age", "grade")) |>
                  modify_caption("**Adding a caption**", text_interpret = "html") |>
