@@ -160,7 +160,7 @@ test_that("modify_spanning_header() works with tbl_cross()", {
 })
 
 test_that("modify_spanning_header() works with tbl_regression()", {
-  skip_if_not(is_pkg_installed("broom.helpers"))
+  skip_if_not(is_pkg_installed(c("cardx", "broom.helpers")))
 
   expect_equal(
     glm(response ~ age + grade, trial, family = binomial()) |>
@@ -174,6 +174,7 @@ test_that("modify_spanning_header() works with tbl_regression()", {
 })
 
 test_that("modify_spanning_header() works with tbl_uvregression()", {
+  skip_if_not(is_pkg_installed(c("cardx", "broom.helpers")))
   expect_equal(
     tbl_uvregression(trial, method = glm, y = response, method.args = list(family = binomial),
                      exponentiate = TRUE, include = c("age", "grade")) |>
