@@ -17,6 +17,11 @@ test_that("style_sigfig() works", {
     style_sigfig(0.97, digits = 1) == "1"
   )
 
+  expect_equal(
+    style_sigfig(NA, na = "NE"),
+    "NE"
+  )
+
   vec2 <- c(one = 0.99, two = 0.0005)
   expect_equal(
     attributes(vec2),
@@ -27,4 +32,9 @@ test_that("style_sigfig() works", {
     style_sigfig(c(0, 1, 11, NA), digits = 2, prefix = "$", suffix = "*"),
     c("$0.00*", "$1.0*", "$11*",  NA)
   )
+
+  expect_equal(
+    style_sigfig(c(0, 1, NA, 11, NA), digits = 2, prefix = "$", suffix = "*", na = "NE"),
+    c("$0.00*", "$1.0*", "NE", "$11*",  "NE")
+  )
 })
