@@ -101,6 +101,20 @@ test_that("tbl_stack(quiet) works", {
   )
 })
 
+test_that("tbl_stack(attr_order) works", {
+  tbl1 <- lm(age ~ trt, trial) |> tbl_regression()
+  tbl2 <- glm(response ~ trt, trial, family = binomial()) |> tbl_regression()
+
+  # check that we get the header from the second table (with the OR in the header)
+  expect_equal(
+    tbl_stack(list(tbl1, tbl2), attr_order = 2) |>
+      as.data.frame() |>
+      names() |>
+      getElement(2),
+    "**log(OR)**"
+  )
+})
+
 test_that("tbl_stack works with no group header", {
   expect_silent(tbl <- tbl_stack(list(t1_summary, t2_summary)))
 
