@@ -585,6 +585,15 @@ test_that("tbl_summary(sort)", {
       dplyr::pull(label),
     c("8", "4", "6")
   )
+
+  # check that sorting does not remove variable label
+  expect_equal(
+    tbl_summary(trial, include = stage, sort = list(stage = "frequency")) |>
+      getElement("table_body") |>
+      getElement("label") |>
+      dplyr::first(),
+    "T Stage"
+  )
 })
 
 test_that("tbl_summary(sort) errors properly", {
@@ -729,3 +738,31 @@ test_that("tbl_summary() column order for lgl by variable", {
   )
 })
 
+test_that("tbl_summary(percent = c(<data.frame>))", {
+  expect_silent(
+    tbl <- cards::ADSL |>
+      dplyr::mutate(DCREASCD = ifelse(DCREASCD == "Completed", NA, DCREASCD)) |>
+      tbl_summary(
+        include = DCREASCD,
+        percent = cards::ADSL,
+        statistic = all_categorical() ~ "{n} / {N} ({p}%)",
+        missing = "no"
+      )
+  )
+  expect_snapshot(as.data.frame(tbl))
+  expect_equal(
+    gather_ard(tbl) |>
+      getElement("tbl_summary") |>
+      dplyr::filter(variable == "DCREASCD", context == "categorical") |>
+      dplyr::select(-gts_column, -fmt_fun),
+    cards::ard_categorical(
+      cards::ADSL |>
+        dplyr::mutate(DCREASCD = ifelse(DCREASCD == "Completed", NA, DCREASCD)),
+      variables = "DCREASCD",
+      denominator = cards::ADSL
+    ) |>
+      dplyr::select(-fmt_fun),
+    ignore_attr = TRUE
+  )
+})
+
