@@ -92,6 +92,40 @@ test_that("pkgwide-str:ci.sep works", {
   )
 })
 
+# tbl_hierarchical-fn:addnl-fn-to-run ------------------------------------
+test_that("tbl_hierarchical_count-fn:addnl-fn-to-run", {
+  expect_s3_class(
+    with_gtsummary_theme(
+      x = list("tbl_hierarchical-fn:addnl-fn-to-run" = as.data.frame),
+      expr =
+        tbl_hierarchical(
+          data = cards::ADAE[1:20,],
+          variables = c(AESOC, AETERM),
+          by = TRTA,
+          denominator = cards::ADSL,
+          id = USUBJID
+        )
+    ),
+    "data.frame"
+  )
+})
+
+# tbl_hierarchical_count-fn:addnl-fn-to-run ------------------------------------
+test_that("tbl_hierarchical_count-fn:addnl-fn-to-run", {
+  expect_s3_class(
+    with_gtsummary_theme(
+      x = list("tbl_hierarchical_count-fn:addnl-fn-to-run" = as.data.frame),
+      expr =
+        tbl_hierarchical_count(
+          data = cards::ADAE[1:20,],
+          variables = c(AESOC, AETERM, AESEV),
+          by = TRTA
+        )
+    ),
+    "data.frame"
+  )
+})
+
 # tbl_summary-arg:missing_stat -------------------------------------------------
 test_that("tbl_summary-arg:missing_stat works", {
   # works with add_difference()
@@ -124,3 +158,33 @@ test_that("tbl_summary-arg:missing_stat works", {
     "7 / 98"
   )
 })
+
+# add_overall.tbl_summary-arg:col_label ----------------------------------------
+test_that("tbl_summary-arg:missing_stat works", {
+  expect_equal(
+    with_gtsummary_theme(
+      x = list("add_overall.tbl_summary-arg:col_label" = "All Participants  \nN = {style_number(N)}"),
+      expr =
+        tbl_summary(trial, include = age, by = trt) |>
+        add_overall(last = TRUE) |>
+        as.data.frame() |>
+        names() |>
+        dplyr::last()
+    ),
+    "All Participants  \nN = 200"
+  )
+
+  expect_equal(
+    with_gtsummary_theme(
+      x = list("add_overall.tbl_summary-arg:col_label" = "All Participants  \nN = {style_number(N)}"),
+      expr =
+        survey::svydesign(~1, data = trial, weights = ~1) |>
+        tbl_svysummary(by = trt, include = age) |>
+        add_overall(last = TRUE) |>
+        as.data.frame() |>
+        names() |>
+        dplyr::last()
+    ),
+    "All Participants  \nN = 200"
+  )
+})
